@@ -10,6 +10,7 @@ import argparse
 import itertools
 import subprocess
 import re
+import sys
 import xml.etree.ElementTree as ET
 from numpy import linspace
 from xml.dom import minidom
@@ -617,6 +618,10 @@ def main():
     action_group.add_argument("-c","--crashes",action='store_true',help="pyGRID will scan the stream files for a job and determine the ones that crashed")
     action_group.add_argument("-r","--resubmit",action='store_true',help="pyGRID will resubmit the crashed jobs parsed from stream files")
 
+    if len(sys.argv) < 2:
+        parser.print_help()
+        sys.exit(1)
+
     # parse the arguments from the command line
     args = parser.parse_args()
 
